@@ -1,4 +1,4 @@
-from Client import Client
+from src.testlab_sdk_python.Client import Client
 
 class Config:
     def __init__(self, server_address, interval):
@@ -7,7 +7,6 @@ class Config:
 
     def connect(self):
         client = Client(self)
-        client.fetch_features()
-        client.add_default_context()
         client.start_in_background()
+        client.add_default_context()
         return client
\ No newline at end of file
